fn sleep_interruptible(duration: Duration, interrupted: &AtomicBool) -> boolExpand description
Sleep up to duration, returning true if interrupted before the deadline.
fn sleep_interruptible(duration: Duration, interrupted: &AtomicBool) -> boolSleep up to duration, returning true if interrupted before the deadline.