fn wait_for_state(
want: &str,
timeout: Duration,
interrupted: &AtomicBool,
) -> boolExpand description
Poll the sched_ext state until it equals want or the timeout elapses.
fn wait_for_state(
want: &str,
timeout: Duration,
interrupted: &AtomicBool,
) -> boolPoll the sched_ext state until it equals want or the timeout elapses.